Enum CameraIndex
pub enum CameraIndex {
Index(u32),
String(String),
}Available on crate feature
camera only.Expand description
Describes the index of the camera.
- Index: A numbered index
- String: A string, used for
IPCameras.
Variants
Implementations
impl CameraIndex
impl CameraIndex
pub fn as_index(&self) -> Result<u32, NokhwaError>
pub fn as_index(&self) -> Result<u32, NokhwaError>
Turns this value into a number. If it is a string, it will attempt to parse it as a u32.
Errors
Fails if the value is not a number.
pub fn as_string(&self) -> String
pub fn as_string(&self) -> String
Turns this value into a String. If it is a number, it will be automatically converted.
pub fn is_index(&self) -> bool
pub fn is_index(&self) -> bool
Returns true if this CameraIndex contains an CameraIndex::Index
pub fn is_string(&self) -> bool
pub fn is_string(&self) -> bool
Returns true if this CameraIndex contains an CameraIndex::String