Struct CameraInfo
pub struct CameraInfo { /* private fields */ }Available on crate feature
camera only.Expand description
Information about a Camera e.g. its name.
description amd misc may contain information that may differ from backend to backend. Refer to each backend for details.
index is a camera’s index given to it by (usually) the OS usually in the order it is known to the system.
Implementations
impl CameraInfo
impl CameraInfo
pub fn new(
human_name: &str,
description: &str,
misc: &str,
index: CameraIndex,
) -> CameraInfo
pub fn new( human_name: &str, description: &str, misc: &str, index: CameraIndex, ) -> CameraInfo
pub fn human_name(&self) -> String
pub fn human_name(&self) -> String
Get a reference to the device info’s human readable name.
JS-WASM
This is exported as a get_HumanReadableName.
pub fn set_human_name(&mut self, human_name: &str)
pub fn set_human_name(&mut self, human_name: &str)
pub fn description(&self) -> &str
pub fn description(&self) -> &str
pub fn set_description(&mut self, description: &str)
pub fn set_description(&mut self, description: &str)
pub fn index(&self) -> &CameraIndex
pub fn index(&self) -> &CameraIndex
pub fn set_index(&mut self, index: CameraIndex)
pub fn set_index(&mut self, index: CameraIndex)